function obj = paraworker( commdir, varargin )

% this = paraworker( commdir, ['poll_intv', poll_intv] )
%
% commdir        communications directory.
% poll_intv      polling interval (in seconds).
%                (a small random shift is added to the given value)
%
% Creates a new worker frontend for a parallelized operation. The calling
% matlab is dedicated to the commdir's jobs via method run().
%
% See also PARAWORKER/RUN, PARAMASTER.


%  This file is a part of the Independent Variable Group Analysis package
% 
%  Copyright (C) 2001-2006 Esa Alhoniemi, Antti Honkela, Krista Lagus,
%  Jeremias Seppa, Harri Valpola, and Paul Wagner
% 
%  This program is free software; you can redistribute it and/or modify
%  it under the terms of the GNU General Public License as published by
%  the Free Software Foundation; either version 2, or (at your option)
%  any later version.
% 
%  This program is distributed in the hope that it will be useful,
%  but WITHOUT ANY WARRANTY; without even the implied warranty of
%  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%  GNU General Public License (included in file License.txt in the
%  program package) for more details.


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

system( 'sleep 1' );
rand( 'state', sum(100*clock) );

% defaults
DEFAULT_POLL_INTV = 3 * 60;
RAND_MAXSHIFT     = 4 * 60;


% check and preprocess args
[flg, poll_intv] = isarg('poll_intv');
if ~flg, poll_intv = DEFAULT_POLL_INTV; end
if commdir(length(commdir)) ~= '/', commdir = [commdir '/']; end
if strfind( commdir, ' ' ), error('No spaces allowed in commdir path!'); end

% generate a unique id
id = num2str( round( 1e6 * rand * sum(100*clock) ), 32 );


% construct the object
this.commdir   = commdir;
this.poll_intv = round(poll_intv + RAND_MAXSHIFT * rand);
this.id        = id;

obj = class( this, 'paraworker' );

return;
