function result = cputimer( this, op )

% 'methods':
%   stats = cputimer( stats, 'start' )
%   stats = cputimer( stats, 'stop' )
%   stats = cputimer( stats, 'reset' ):   does not stop the timer!
%   elapsed = cputimer( stats ):   returns elapsed cpu time in seconds
%
% Initialized in stats constructor. Will not restart until all 'stop' calls are
% matched with a 'start' call. Also extra 'start' calls are accumulated.  Does
% not depend on the stats object's activation state.


%  This file is a part of the Independent Variable Group Analysis package
% 
%  Copyright (C) 2001-2006 Esa Alhoniemi, Antti Honkela, Krista Lagus,
%  Jeremias Seppa, Harri Valpola, and Paul Wagner
% 
%  This program is free software; you can redistribute it and/or modify
%  it under the terms of the GNU General Public License as published by
%  the Free Software Foundation; either version 2, or (at your option)
%  any later version.
% 
%  This program is distributed in the hope that it will be useful,
%  but WITHOUT ANY WARRANTY; without even the implied warranty of
%  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%  GNU General Public License (included in file License.txt in the
%  program package) for more details.


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


if this.cputimer.active > 0
  this.cputimer.elapsed = ...
      this.cputimer.elapsed + (cputime - this.cputimer.lasttime);
end

elapsed = this.cputimer.elapsed;


if nargin == 2
  
  switch op
    
   case 'start'
    this.cputimer.active = this.cputimer.active + 1;
    this.cputimer.lasttime = cputime;
    
   case 'stop'
    this.cputimer.active = this.cputimer.active - 1;
    
   case 'reset'
    this.cputimer.elapsed = 0.0;
    this.cputimer.lasttime = cputime;
    
  end
  
  result = this;
  
else
  
  result = elapsed;
  
end
