function results = get_res( this, op, vars, mode )

% results = get_res( this, op, vars, mode )
%
% op        source operation's name, or [] to get all results.
% vars      either a cell array containing variable names, or []. first
%           returns only the specified variables in that order. [] returns
%           all variables.
% mode      either 'iters' (view results at iteration level) or 'calls'
%           (view results at call level). Call level operation is done very
%           inefficiently, and its not intended to be used during main
%           computations.
%
% Example:
%   eff = get_res( STATS, 'Merge', {'efficiency'}, 'calls' )


%  This file is a part of the Independent Variable Group Analysis package
% 
%  Copyright (C) 2001-2006 Esa Alhoniemi, Antti Honkela, Krista Lagus,
%  Jeremias Seppa, Harri Valpola, and Paul Wagner
% 
%  This program is free software; you can redistribute it and/or modify
%  it under the terms of the GNU General Public License as published by
%  the Free Software Foundation; either version 2, or (at your option)
%  any later version.
% 
%  This program is distributed in the hope that it will be useful,
%  but WITHOUT ANY WARRANTY; without even the implied warranty of
%  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%  GNU General Public License (included in file License.txt in the
%  program package) for more details.



% Some functionality in 'calls' is duplicated from get_value (for speed
% reasons). Remember to keep these methods in sync!  'cputimer', 'total cost'
% and 'efficiency' variables' indices are hardcoded here!

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


switch mode
  
 case 'iters'
  
  if isempty(op)
    results = get_results( this );
  else
    if isempty(vars)
      results = get_results( this, op );
    else
      results = get_results( this, op, vars );
    end
  end
  
  
 case 'calls'
  
  areas  = get_areas( this, op );
  ncalls = length(areas) - 1;
  if ncalls == 0
    if isempty(vars)
      nvars = length(get_var_names(this, op)) + 3;
    else
      nvars = length(vars);
    end
    results = zeros( 0, nvars );
    return;
  end
  
  table = this.results{get_op_ind(this, op)};
  rows_start = areas( 1:length(areas)-1 );
  rows_end   = areas( 2:length(areas) ) - 1;
  results = table(rows_end,:) - table(rows_start,:);
  
  % recompute the efficiencies
  ind1 = results(:,1) == 0 & results(:,2) == 0;
  ind2 = results(:,1) == 0 & results(:,2) ~= 0;
  ind3 = ~ind1 & ~ind2;
  results(ind1,3) = 0;
  results(ind2,3) = NaN;
  results(ind3,3) = - results(ind3,2) ./ results(ind3,1);
  
  results = [ results, rows_end - rows_start, ...
              table(rows_start, 1), table(rows_end, 1) ];
  
  if ~isempty(vars)
    n = [];
    for i=1:length(vars)
      n = [ n, get_var_ind( this, op, vars{i} ) ];
    end
    results = results( :, n );
  end
  
  
end  

return;
