function object = trigger_fraction( fraction, peak_scan_time, input )

% object = trigger_fraction( fraction, peak_scan_time, input )
%
% Triggers when the input level drops below the specified fraction of its
% starting value. The starting value is considered as the peak level found
% from 'peak_scan_time' first samples.
%
% If the measured starting value is zero, then the trigger activates
% immediately after the peak scan phase.
%
% The input should have only one channel currently.


%  This file is a part of the Independent Variable Group Analysis package
% 
%  Copyright (C) 2001-2006 Esa Alhoniemi, Antti Honkela, Krista Lagus,
%  Jeremias Seppa, Harri Valpola, and Paul Wagner
% 
%  This program is free software; you can redistribute it and/or modify
%  it under the terms of the GNU General Public License as published by
%  the Free Software Foundation; either version 2, or (at your option)
%  any later version.
% 
%  This program is distributed in the hope that it will be useful,
%  but WITHOUT ANY WARRANTY; without even the implied warranty of
%  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%  GNU General Public License (included in file License.txt in the
%  program package) for more details.


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


% define the class so that matlab recognizes it when loading objects
if nargin == 0
  this.enabled            = [];
  this.fraction           = [];
  this.input              = [];
  this.peak_scan_time     = [];
  this.peak_scan_left     = [];
  this.peak               = [];
  this.level              = [];
  object = class( this, 'trigger_fraction' );
  return;
end


this.enabled            = 0;
this.fraction           = fraction;
this.input              = input;

this.peak_scan_time     = peak_scan_time;
this.peak_scan_left     = [];
this.peak               = [];
this.level              = [];


object = class( this, 'trigger_fraction' );
return;
