function Output = display_batch_groups(Summary, N, show_details, nodisplay)



%  This file is a part of the Independent Variable Group Analysis package
% 
%  Copyright (C) 2001-2006 Esa Alhoniemi, Antti Honkela, Krista Lagus,
%  Jeremias Seppa, Harri Valpola, and Paul Wagner
% 
%  This program is free software; you can redistribute it and/or modify
%  it under the terms of the GNU General Public License as published by
%  the Free Software Foundation; either version 2, or (at your option)
%  any later version.
% 
%  This program is distributed in the hope that it will be useful,
%  but WITHOUT ANY WARRANTY; without even the implied warranty of
%  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%  GNU General Public License (included in file License.txt in the
%  program package) for more details.

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

n = length(N);

for i = 1:length(Summary.Groups)
  NVars(i) = length(Summary.Groups{i});
end

Output{1} = {Summary.Groups{N}};
Output{2} = Summary.GroupFreqs(N);

if nodisplay, return; end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% display variables

subplot(1, 2, 1)

Y = ones(n, Summary.nvars);
for i = 1:n
  Y(i, Output{1}{i}) = 0;
end
imagesc(Y)

set(gca, 'ytick', 1:n, 'yticklabel', N, 'yaxislocation', 'right');
colormap(gray(2))
xlabel('Variable(s)')

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% display frequencies

subplot(1, 2, 2)

hold on
flg = 1;

for i = 1:n
  h = barh(i, Output{2}(i));

  % construct callbacks (extra fucntionality)
  
  Str = ['figure; plot(['];
  X = sprintf('%d ', Summary.GroupNCentroids{N(i)});
  Y = sprintf('%d ', Summary.GroupCosts{N(i)});
  Str = ['figure; plot([' X '], [' Y '],' '''' 'ko' '''' ',' '''' ...
         'markerfacecolor' '''' ',' '''' 'k' '''' '); axis tight;' ...
                      'xlabel(' '''' 'No of centroids' '''' '); ' ...
                      'ylabel(' '''' 'Cost' '''' ');'];

  set(h, 'buttondownfcn', Str, 'facecolor', 'k');
end

set(gca, 'ytick', 1:n, 'yticklabel', N, 'ydir', 'reverse');

xlabel('Frequency')
ylabel('Group')
axis tight

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

